--
-- PartSwitcher
--
-- @author:    	Xentro (www.fs-uk.com)(Marcus@Xentro.se)
-- @version:    v1.0
-- @date:       2013-11-01
-- 
--[[
<PartSwitcher resetOnEmpty="BOOL" >
	<part index="INDEX" fillTypes="FILLTYPE FILLTYPE" />
	<part index="INDEX" fillTypes="FILLTYPE FILLTYPE" />
</PartSwitcher>
]]--

PartSwitcher = {};

function PartSwitcher.prerequisitesPresent(specializations)
	if not SpecializationUtil.hasSpecialization(Fillable, specializations) then print("Warning: Specialization PartSwitcher needs the specialization Fillable."); end;
	
	return SpecializationUtil.hasSpecialization(Fillable, specializations);
end;

function PartSwitcher:load(xmlFile)
	self.setFillLevel = Utils.appendedFunction(self.setFillLevel, PartSwitcher.setFillLevel);
	
	self.parts = {};
	local i = 0;
	while true do
		local key = string.format("vehicle.PartSwitcher.part(%d)", i);
		if not hasXMLProperty(xmlFile, key) then break; end;
		
		local node = Utils.indexToObject(self.components, getXMLString(xmlFile, key .. "#index"));
		if node ~= nil then
			local fillTypes = getXMLString(xmlFile, key .. "#fillTypes");
			if fillTypes ~= nil and fillTypes ~= "" then
				local entry = {};
				entry.node = node;
				entry.fillTypes = {};
				
				setVisibility(entry.node, false);
				
				local types = Utils.splitString(" ", fillTypes);
				for k, v in pairs(types) do
					local fillType = Fillable.fillTypeNameToInt[v];
					if fillType ~= nil then
						entry.fillTypes[fillType] = true;
					else
						print("PartSwitcher - Warning: '" .. self.configFileName .. "' has invalid fillType '" .. v .. "'.");
					end;
				end;
				
				if table.getn(entry.fillTypes) > 0 then
					table.insert(self.parts, entry);
					i = i + 1;
				else
					print("PartSwitcher - Warning: 0 valid filltypes is an invalid amount.");
					break;
				end;
			else
				print("PartSwitcher - Warning: There are no fillTypes.");
				break;
			end;
		else
			print("PartSwitcher - Error: Part index is empty.");
			break;
		end;
	end;
	
	self.resetOnEmpty = Utils.getNoNil(getXMLBool(xmlFile, "vehicle.PartSwitcher#resetOnEmpty"), false);
end;

function PartSwitcher:delete()
end;

function PartSwitcher:mouseEvent(posX, posY, isDown, isUp, button)
end;

function PartSwitcher:keyEvent(unicode, sym, modifier, isDown)
end;

function PartSwitcher:update(dt)
end;

function PartSwitcher:draw()
end;

function PartSwitcher:setFillLevel(fillLevel, fillType, force)
	for _, v in ipairs(self.parts) do
		if v.fillTypes[self.currentFillType] ~= nil and v.fillTypes[self.currentFillType] then
			setVisibility(v.node, true);
		else
			if self.currentFillType == Fillable.FILLTYPE_UNKNOWN then
				if self.resetOnEmpty then
					setVisibility(v.node, false);
				end;
			else
				setVisibility(v.node, false);
			end;
		end;
	end;
end;